Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var CheckPeriod = 60
CheckPeriod time between checking on a pool
var CoinMineAPIKey string
CoinMineAPIKey is the api key to use to access coinmine metrics
var MiningDutchAPIKey string
MiningDutchAPIKey api key for polling the mining dutch mining pool
Functions ¶
Types ¶
type CoinMineResult ¶
type CoinMineResult struct {
Getpoolstatus struct {
Version string `json:"version"`
Runtime float64 `json:"runtime"`
Data struct {
PoolName string `json:"pool_name"`
Hashrate float64 `json:"hashrate"`
Efficiency float64 `json:"efficiency"`
Progress float64 `json:"progress"`
Workers int `json:"workers"`
Currentnetworkblock int `json:"currentnetworkblock"`
Nextnetworkblock int `json:"nextnetworkblock"`
Lastblock int `json:"lastblock"`
Networkdiff float64 `json:"networkdiff"`
Esttime float64 `json:"esttime"`
Estshares int64 `json:"estshares"`
Timesincelast int `json:"timesincelast"`
Nethashrate float64 `json:"nethashrate"`
} `json:"data"`
} `json:"getpoolstatus"`
}
CoinMineResult holds the data returned from the CoinMine API
type MiningDutchResponse ¶
type MiningDutchResponse struct {
Getpoolhashrate struct {
Version string `json:"version"`
Runtime float64 `json:"runtime"`
Data float64 `json:"data"`
} `json:"getpoolhashrate"`
}
MiningDutchResponse holds the data returned from the Mining Dutch API
Click to show internal directories.
Click to hide internal directories.